pub enum OfferingStatus {
Active,
Inactive,
Discontinued,
}Expand description
Location-level offering status used to prevent inactive or discontinued products from being sold.
Variants
Active
Offering can be considered for sale or recommendation if usage and inventory also allow it.
Inactive
Offering is disabled at the location and must not be sold or recommended.
Discontinued
Offering has been retired and should remain out of staff sale and recommendation drafts.