pub enum Category {
Supplement,
InHouseDiet,
PersonalizedUpsell,
}Expand description
Product category used to distinguish supplements, boarding diets, and personalized upsell items.
Variants
Supplement
Supplement retail operational signal for inventory, POS, reorder, recommendation, or review handling.
InHouseDiet
In house diet retail operational signal for inventory, POS, reorder, recommendation, or review handling.
PersonalizedUpsell
Personalized upsell retail operational signal for inventory, POS, reorder, recommendation, or review handling.